@@ -6,6 +6,11 @@ import typing
 
 from lime_etl.domain import exceptions, job_test_result, value_objects
 
+__all__ = (
+    "JobResultDTO",
+    "JobResult",
+)
+
 
 @dataclasses.dataclass(unsafe_hash=True)
 class JobResultDTO:
