@@ -14,14 +14,13 @@ from lime_etl.adapters import (
     timestamp_adapter,
 )
 
+__all__ = (
+    "AdminUnitOfWork",
+    "SqlAlchemyAdminUnitOfWork",
+)
+
 
 class AdminUnitOfWork(lu.UnitOfWork, abc.ABC):
-    def __enter__(self) -> AdminUnitOfWork:
-        return typing.cast(AdminUnitOfWork, super().__enter__())
-
-    def __exit__(self, *args) -> None:  # type: ignore
-        super().__exit__(*args)
-
     @property
     @abc.abstractmethod
     def batch_repo(self) -> batch_repository.BatchRepository:
@@ -42,12 +41,17 @@ class AdminUnitOfWork(lu.UnitOfWork, abc.ABC):
     def job_log_repo(self) -> job_log_repository.JobLogRepository:
         raise NotImplementedError
 
+    @property
+    @abc.abstractmethod
+    def ts_adapter(self) -> timestamp_adapter.TimestampAdapter:
+        raise NotImplementedError
+
 
 class SqlAlchemyAdminUnitOfWork(AdminUnitOfWork):
     def __init__(
         self,
         shared_resources: lu.SharedResources,
-        ts_adapter: timestamp_adapter.TimestampAdapter = timestamp_adapter.LocalTimestampAdapter()
+        ts_adapter: timestamp_adapter.TimestampAdapter = timestamp_adapter.LocalTimestampAdapter(),
     ):
         self._ts_adapter = ts_adapter
 
@@ -73,7 +77,9 @@ class SqlAlchemyAdminUnitOfWork(AdminUnitOfWork):
     def ts_adapter(self) -> timestamp_adapter.TimestampAdapter:
         return self._ts_adapter
 
-    def create_resources(self, shared_resources: lu.SharedResources) -> typing.Set[lu.Resource[typing.Any]]:
+    def create_resources(
+        self, shared_resources: lu.SharedResources
+    ) -> typing.Set[lu.Resource[typing.Any]]:
         session = shared_resources.get(admin_session.SqlAlchemyAdminSession)
         return {
             batch_repository.SqlAlchemyBatchRepository(
@@ -87,5 +93,5 @@ class SqlAlchemyAdminUnitOfWork(AdminUnitOfWork):
             ),
             job_log_repository.SqlAlchemyJobLogRepository(
                 session=session, ts_adapter=self._ts_adapter
-            )
+            ),
         }
