@@ -6,19 +6,20 @@ import lime_uow as lu
 
 from lime_etl.adapters import timestamp_adapter
 from lime_etl.domain import (
-    batch,
+    batch_result,
     exceptions,
     job_dependency_errors,
-    job_result,
-    job_spec,
-    value_objects,
+    job_result, value_objects,
 )
 from lime_etl.services import (
     admin_unit_of_work,
     batch_logging_service,
     job_runner,
+    job_spec,
 )
 
+__all__ = ("run",)
+
 
 def run(
     *,
@@ -30,7 +31,7 @@ def run(
     logger: batch_logging_service.BatchLoggingService,
     skip_tests: bool,
     ts_adapter: timestamp_adapter.TimestampAdapter,
-) -> batch.Batch:
+) -> batch_result.BatchResult:
     start_time = ts_adapter.now()
     try:
         dep_results = check_dependencies(jobs)
@@ -38,7 +39,7 @@ def run(
             raise exceptions.DependencyErrors(dep_results)
 
         with admin_uow as uow:
-            new_batch = batch.Batch(
+            new_batch = batch_result.BatchResult(
                 id=batch_id,
                 name=batch_name,
                 job_results=frozenset(),
@@ -56,8 +57,8 @@ def run(
             batch_id=batch_id,
             batch_logger=logger,
             batch_name=batch_name,
-            jobs=jobs,
             batch_uow=batch_uow,
+            jobs=jobs,
             skip_tests=skip_tests,
             start_time=start_time,
             ts_adapter=ts_adapter,
@@ -73,7 +74,7 @@ def run(
         logger.log_error(str(e))
         end_time = ts_adapter.now()
         with admin_uow as uow:
-            result = batch.Batch(
+            result = batch_result.BatchResult(
                 id=batch_id,
                 name=batch_name,
                 job_results=frozenset(),
@@ -156,7 +157,7 @@ def _run_batch(
     skip_tests: bool,
     start_time: value_objects.Timestamp,
     ts_adapter: timestamp_adapter.TimestampAdapter,
-) -> batch.Batch:
+) -> batch_result.BatchResult:
     _check_for_duplicate_job_names(jobs)
 
     job_results: typing.List[job_result.JobResult] = []
@@ -169,10 +170,10 @@ def _run_batch(
             seconds_since_last_refresh = (
                 current_ts.value - last_ts.value
             ).total_seconds()
-            if seconds_since_last_refresh < job.seconds_between_refreshes.value:
+            if seconds_since_last_refresh < job.min_seconds_between_refreshes.value:
                 batch_logger.log_info(
                     f"[{job.job_name.value}] was run successfully {seconds_since_last_refresh:.0f} seconds "
-                    f"ago and it is set to refresh every {job.seconds_between_refreshes.value} seconds, "
+                    f"ago and it is set to refresh every {job.min_seconds_between_refreshes.value} seconds, "
                     f"so there is no need to refresh again."
                 )
                 continue
@@ -197,11 +198,11 @@ def _run_batch(
         try:
             result = job_runner.default_job_runner(
                 admin_uow=admin_uow,
+                batch_uow=batch_uow,
                 job=job,
                 logger=job_logger,
                 batch_id=batch_id,
                 job_id=job_id,
-                batch_uow=batch_uow,
                 skip_tests=skip_tests,
                 ts_adapter=ts_adapter,
             )
@@ -229,7 +230,7 @@ def _run_batch(
     end_time = ts_adapter.now()
 
     execution_millis = int((end_time.value - start_time.value).total_seconds() * 1000)
-    return batch.Batch(
+    return batch_result.BatchResult(
         id=batch_id,
         name=batch_name,
         execution_millis=value_objects.ExecutionMillis(execution_millis),
